@@ -1,5 +1,5 @@
 package Statistics::Descriptive::Sparse;
-$Statistics::Descriptive::Sparse::VERSION = '3.0700';
+$Statistics::Descriptive::Sparse::VERSION = '3.0701';
 use strict;
 use warnings;
 
@@ -230,7 +230,7 @@ Statistics::Descriptive - Module of basic descriptive statistical functions.
 
 =head1 VERSION
 
-version 3.0700
+version 3.0701
 
 =head1 SYNOPSIS
 
@@ -262,7 +262,7 @@ calls with the same arguments are faster.
 
 =head1 VERSION
 
-version 3.0700
+version 3.0701
 
 =head1 METHODS
 
@@ -551,7 +551,7 @@ B<$Type> is an integer value between 0 to 4 :
   3 => third quartile (Q3) : upper quartile = highest cut off (25%) of data, or lowest 75% = 75th percentile
   4 => fourth quartile (Q4) : maximal value
 
-Exemple :
+Example :
 
   my @data = (1..10);
   my $stat = Statistics::Descriptive::Full->new();
@@ -578,7 +578,7 @@ Returns the geometric mean of the data.
 
 =item my $mode = $stat->mode();
 
-Returns the mode of the data. The mode is the most commonly occuring datum.
+Returns the mode of the data. The mode is the most commonly occurring datum.
 See L<http://en.wikipedia.org/wiki/Mode_%28statistics%29> . If all values
 occur only once, then mode() will return undef.
 
